# picachain
A simple ready-to-use image search library

## 📌 Install Picachain
Create a local datastore with **ChromaDB** for image search.

With `pip` :
```bash
pip install picachain
```

With `poetry` :
```bash
poetry add picachain
```

## Create a Picachain Image search engine.
With less than 10 lines of code, create an image search engine with the help of **picachain** and **chromadb**.





